# BMP180

Bosch Digital Temperature / Pressure Sensor

- Device address 119
- Address type 7-bit

### Addr 170 16-bytes Read-only | # Pressure calibration AC1 ## For calibration
### Addr 172 16-bytes Read-only | # Pressure calibration AC2 ## For calibration
### Addr 174 16-bytes Read-only | # Temperature calibration 3 ## For calibration
### Addr 176 16-bytes Read-only | # Temperature calibration 4 ## For calibration
### Addr 178 16-bytes Read-only | # Temperature calibration 5 ## For calibration
### Addr 180 16-bytes Read-only | # Temperature calibration 6 ## For calibration
### Addr 182 16-bytes Read-only | # Pressure calibration VB1 ## For calibration
### Addr 184 16-bytes Read-only | # Pressure calibration VB2 ## For calibration
### Addr 188 16-bytes Read-only | # Temperature calibration MC ## For calibration
### Addr 190 16-bytes Read-only | # Temperature calibration MD ## For calibration
### Addr 244 8-bytes Write-only | # Register to write commands ## Register stores what the measurement type should be |
### Addr 246 16-bytes Read-only | # Register that stores measurement results ## Register stores most recent measurement result

## Functions

- temperature.asCelsius - Reads the temperature